@@ -21,7 +21,7 @@ OS's bugs.
 
 Declare a dependency on the @regex-tdfa@ library in your @.cabal@ file:
 
-> build-depends: regex-tdfa ^>= 1.3.1.1
+> build-depends: regex-tdfa ^>= 1.3.2
 
 In Haskell modules where you want to use regexes simply @import@ /this/ module:
 
@@ -32,9 +32,18 @@ import "Text.Regex.TDFA"
 = Basics
 
 @
-λ> let emailRegex = "[a-zA-Z0-9+.\_-]+\@[a-zA-Z-]+\\\\.[a-z]+"
-λ> "my email is email@email.com" '=~' emailRegex :: Bool
->>> True
+>>> let emailRegex = "[a-zA-Z0-9+._-]+\\@[-a-zA-Z]+\\.[a-z]+"
+>>> "my email is first-name.lastname_1974@e-mail.com" =~ emailRegex :: Bool
+True
+
+>>> "invalid@mail@com" =~ emailRegex :: Bool
+False
+
+>>> "invalid@mail.COM" =~ emailRegex :: Bool
+False
+
+>>> "#@invalid.com" =~ emailRegex :: Bool
+False
 
 /-- non-monadic/
 λ> \<to-match-against\> '=~' \<regex\>
@@ -61,11 +70,12 @@ type you want, especially if you're trying things out at the REPL.
 /-- returns empty string if no match/
 a '=~' b :: String  /-- or ByteString, or Text.../
 
-λ> "alexis-de-tocqueville" '=~' "[a-z]+" :: String
->>> "alexis"
+>>> "alexis-de-tocqueville" =~ "[a-z]+" :: String
+"alexis"
+
+>>> "alexis-de-tocqueville" =~ "[0-9]+" :: String
+""
 
-λ> "alexis-de-tocqueville" '=~' "[0-9]+" :: String
->>> ""
 @
 
 == Check if it matched at all
@@ -73,8 +83,9 @@ a '=~' b :: String  /-- or ByteString, or Text.../
 @
 a '=~' b :: Bool
 
-λ> "alexis-de-tocqueville" '=~' "[a-z]+" :: Bool
->>> True
+>>> "alexis-de-tocqueville" =~ "[a-z]+" :: Bool
+True
+
 @
 
 == Get first match + text before/after
@@ -84,11 +95,12 @@ a '=~' b :: Bool
 /-- string in the first element of the tuple/
 a =~ b :: (String, String, String)
 
-λ> "alexis-de-tocqueville" '=~' "de" :: (String, String, String)
->>> ("alexis-", "de", "-tocqueville")
+>>> "alexis-de-tocqueville" =~ "de" :: (String, String, String)
+("alexis-","de","-tocqueville")
+
+>>> "alexis-de-tocqueville" =~ "kant" :: (String, String, String)
+("alexis-de-tocqueville","","")
 
-λ> "alexis-de-tocqueville" '=~' "kant" :: (String, String, String)
->>> ("alexis-de-tocqueville", "", "")
 @
 
 == Get first match + submatches
@@ -98,8 +110,9 @@ a =~ b :: (String, String, String)
 /-- submatch list is empty if regex doesn't match at all/
 a '=~' b :: (String, String, String, [String])
 
-λ> "div[attr=1234]" '=~' "div\\\\[([a-z]+)=([^]]+)\\\\]" :: (String, String, String, [String])
->>> ("", "div[attr=1234]", "", ["attr","1234"])
+>>> "div[attr=1234]" =~ "div\\[([a-z]+)=([^]]+)\\]" :: (String, String, String, [String])
+("","div[attr=1234]","",["attr","1234"])
+
 @
 
 == Get /all/ matches
@@ -108,8 +121,12 @@ a '=~' b :: (String, String, String, [String])
 /-- can also return Data.Array instead of List/
 'getAllTextMatches' (a '=~' b) :: [String]
 
-λ> 'getAllTextMatches' ("john anne yifan" '=~' "[a-z]+") :: [String]
->>> ["john","anne","yifan"]
+>>> getAllTextMatches ("john anne yifan" =~ "[a-z]+") :: [String]
+["john","anne","yifan"]
+
+>>> getAllTextMatches ("* - . a + z" =~ "[--z]+") :: [String]
+["-",".","a","z"]
+
 @
 
 = Feature support
@@ -143,6 +160,12 @@ just [a].  The character classes like [:alnum:] are supported over
 ASCII only, valid classes are alnum, digit, punct, alpha, graph,
 space, blank, lower, upper, cntrl, print, xdigit, word.
 
+@
+>>> getAllTextMatches ("john anne yifan" =~ "[[:lower:]]+") :: [String]
+["john","anne","yifan"]
+
+@
+
 This package does not provide "basic" regular expressions.  This
 package does not provide back references inside regular expressions.
 
@@ -165,7 +188,7 @@ import Text.RawString.QQ
 import Text.Regex.TDFA
 
 λ> "2 * (3 + 1) / 4" '=~' [r|\\([^)]+\\)|] :: String
->>> "(3 + 1)"
+"(3 + 1)"
 @
 
 -}
